==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_cpf.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=cpf
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Ladrès out sitwèb', # MODIF
	'form_pet_aucune_signature' => 'Astèr, nana pwinn sinyatir èk kod la-minm...', # MODIF
	'form_pet_confirmation' => 'Mersi konfirm tèrla out sinyatir :',
	'form_pet_deja_signe' => 'Ou la déza finn sinyé lo tèks-la.',
	'form_pet_envoi_mail_confirmation' => 'Inn limèl pou konfirmé la finn dèt anvwayé aou. Li donn aou inn ladrès sitwèb. Lé nésésèr ou sava bat-karé sir lo sit-la pou konfirm vréman out sinyatir.', # MODIF
	'form_pet_mail_confirmation' => 'Oté,

Ou la domman sinyé lo filsinyatir-la :
@titre@.

Ou la doné bann ranséynman  swivan :
    Nom : @nom_email@
    Site : @nom_site@ - @url_site@

PANGAR...

Pou konfirm out sinyatir-la, i fo sèlman akost ladrès anba (si lé pa fé, sitwèb-la i sava pa antyen kon out doman) :
    @url@

Mersi aou mèt ansanm isi
',
	'form_pet_nom_site2' => '<b>Lo non out sitwèb ', # MODIF
	'form_pet_probleme_liens' => 'Arpran out’ mèzaz pou siprim bann gatiraz.',
	'form_pet_probleme_technique' => 'Astèr, nana inn larlik èk latéknik : bann sinyatir lé baré pou inn moman.',
	'form_pet_signature_validee' => 'Out sinyatir lé konfirmé. Mersi aou !',
	'form_pet_site_deja_enregistre' => 'Sitwèb-la la déza finn dèt anrozistré',
	'form_pet_url_invalide' => 'Ladrès URL ou la finn doné lé pa korèk.',
	'form_pet_votre_email' => 'Out ladrès imèl',
	'form_pet_votre_nom' => 'Out vrénon ou ti-non-gaté', # MODIF
	'form_pet_votre_site' => 'Si out néna out prop sitwèb, i pé mèt ali anba tèrla :',

	// I
	'info_adresse_email' => 'LADRES IMEL :',
	'info_site_web' => 'SITWÈB :',

	// L
	'lien_reponse_article' => 'Réponn lartik-la'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_cpf.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=cpf
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Fé zwé filsinyatir',
	'bouton_radio_pas_petition' => 'Anpès néna filsinyatir',
	'bouton_radio_petition_activee' => 'Astèr, filsinyatir i mars',
	'bouton_radio_supprimer_petition' => 'Dégrèn filsinyatir',

	// F
	'form_pet_adresse_site' => 'Ladrès out sitwèb', # MODIF
	'form_pet_aucune_signature' => 'Astèr, nana pwinn sinyatir èk kod la-minm...', # MODIF
	'form_pet_confirmation' => 'Mersi konfirm tèrla out sinyatir :',
	'form_pet_deja_signe' => 'Ou la déza finn sinyé lo tèks-la.',
	'form_pet_envoi_mail_confirmation' => 'Inn limèl pou konfirmé la finn dèt anvwayé aou. Li donn aou inn ladrès sitwèb. Lé nésésèr ou sava bat-karé sir lo sit-la pou konfirm vréman out sinyatir.', # MODIF
	'form_pet_mail_confirmation' => 'Oté,

Ou la domman sinyé lo filsinyatir-la :
@titre@.

Ou la doné bann ranséynman  swivan :
    Nom : @nom_email@
    Site : @nom_site@ - @url_site@

PANGAR...

Pou konfirm out sinyatir-la, i fo sèlman akost ladrès anba (si lé pa fé, sitwèb-la i sava pa antyen kon out doman) :
    @url@

Mersi aou mèt ansanm isi
',
	'form_pet_nom_site2' => '<b>Lo non out sitwèb ', # MODIF
	'form_pet_probleme_liens' => 'Arpran out’ mèzaz pou siprim bann gatiraz.',
	'form_pet_probleme_technique' => 'Astèr, nana inn larlik èk latéknik : bann sinyatir lé baré pou inn moman.',
	'form_pet_signature_validee' => 'Out sinyatir lé konfirmé. Mersi aou !',
	'form_pet_site_deja_enregistre' => 'Sitwèb-la la déza finn dèt anrozistré',
	'form_pet_url_invalide' => 'Ladrès URL ou la finn doné lé pa korèk.',
	'form_pet_votre_email' => 'Out ladrès imèl',
	'form_pet_votre_nom' => 'Out vrénon ou ti-non-gaté', # MODIF
	'form_pet_votre_site' => 'Si out néna out prop sitwèb, i pé mèt ali anba tèrla :',

	// I
	'info_adresse_email' => 'LADRES IMEL :',
	'info_site_web' => 'SITWÈB :',

	// L
	'lien_reponse_article' => 'Réponn lartik-la'
);

?>
